# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ingestion.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'ingestion.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import data_type_pb2 as data__type__pb2
from . import file_format_type_pb2 as file__format__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fingestion.proto\x12\x12\x63z.proto.ingestion\x1a\x0f\x64\x61ta_type.proto\x1a\x16\x66ile_format_type.proto\"^\n\x0eGatewayRequest\x12\x17\n\x0fmethodEnumValue\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\ninstanceId\x18\x03 \x01(\x03\x12\x0e\n\x06userId\x18\x04 \x01(\x03\"]\n\x0fGatewayResponse\x12\x39\n\x06status\x18\x01 \x01(\x0b\x32).cz.proto.ingestion.GateWayResponseStatus\x12\x0f\n\x07message\x18\x02 \x01(\t\"\\\n\x0eUserIdentifier\x12\x13\n\x0binstance_id\x18\x01 \x01(\x03\x12\x11\n\tworkspace\x18\x02 \x01(\t\x12\x11\n\tuser_name\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\x03\"P\n\x07\x41\x63\x63ount\x12\x36\n\nuser_ident\x18\x01 \x01(\x0b\x32\".cz.proto.ingestion.UserIdentifier\x12\r\n\x05token\x18\x02 \x01(\t\"b\n\x0fTableIdentifier\x12\x13\n\x0binstance_id\x18\x01 \x01(\x03\x12\x11\n\tworkspace\x18\x02 \x01(\t\x12\x13\n\x0bschema_name\x18\x03 \x01(\t\x12\x12\n\ntable_name\x18\x04 \x01(\t\"d\n\x15GateWayResponseStatus\x12&\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x18.cz.proto.ingestion.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\t\"c\n\x0eResponseStatus\x12&\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x18.cz.proto.ingestion.Code\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x12\n\nrequest_id\x18\x03 \x01(\t\";\n\tDataField\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.cz.proto.DataType\"R\n\x10\x44istributionSpec\x12\x11\n\tfield_ids\x18\x01 \x03(\r\x12\x16\n\x0ehash_functions\x18\x02 \x03(\t\x12\x13\n\x0bnum_buckets\x18\x03 \x01(\r\"#\n\x0ePrimaryKeySpec\x12\x11\n\tfield_ids\x18\x01 \x03(\r\"&\n\rPartitionSpec\x12\x15\n\rsrc_field_ids\x18\x01 \x03(\r\"\xf4\x01\n\x0cStreamSchema\x12\x32\n\x0b\x64\x61ta_fields\x18\x01 \x03(\x0b\x32\x1d.cz.proto.ingestion.DataField\x12\x37\n\tdist_spec\x18\x02 \x01(\x0b\x32$.cz.proto.ingestion.DistributionSpec\x12<\n\x10primary_key_spec\x18\x03 \x01(\x0b\x32\".cz.proto.ingestion.PrimaryKeySpec\x12\x39\n\x0epartition_spec\x18\x04 \x01(\x0b\x32!.cz.proto.ingestion.PartitionSpec\"\x97\x01\n\x18\x43reateOrGetStreamRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x38\n\x0btable_ident\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x13\n\x0bnum_tablets\x18\x03 \x01(\r\"\xd8\x01\n\x19\x43reateOrGetStreamResponse\x12\x38\n\x0btable_ident\x18\x01 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x35\n\x0b\x64\x61ta_schema\x18\x02 \x01(\x0b\x32 .cz.proto.ingestion.StreamSchema\x12\x16\n\x0e\x61lready_exists\x18\x03 \x01(\x08\x12\x32\n\x06status\x18\x04 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\"|\n\x12\x43loseStreamRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x38\n\x0btable_ident\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\"I\n\x13\x43loseStreamResponse\x12\x32\n\x06status\x18\x01 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\"\xad\x01\n\x12OssStagingPathInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tsts_ak_id\x18\x03 \x01(\t\x12\x15\n\rsts_ak_secret\x18\x04 \x01(\t\x12\x11\n\tsts_token\x18\x05 \x01(\t\x12\x14\n\x0coss_endpoint\x18\x06 \x01(\t\x12\x1d\n\x15oss_internal_endpoint\x18\x07 \x01(\t\x12\x17\n\x0foss_expire_time\x18\x08 \x01(\x04\"\x8c\x01\n\x12\x43osStagingPathInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tsts_ak_id\x18\x02 \x01(\t\x12\x15\n\rsts_ak_secret\x18\x03 \x01(\t\x12\x11\n\tsts_token\x18\x04 \x01(\t\x12\x12\n\ncos_region\x18\x05 \x01(\t\x12\x17\n\x0f\x63os_expire_time\x18\x06 \x01(\x04\"\x89\x01\n\x11S3StagingPathInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tsts_ak_id\x18\x02 \x01(\t\x12\x15\n\rsts_ak_secret\x18\x03 \x01(\t\x12\x11\n\tsts_token\x18\x04 \x01(\t\x12\x11\n\ts3_region\x18\x05 \x01(\t\x12\x16\n\x0es3_expire_time\x18\x06 \x01(\x04\"\x8c\x01\n\x12GcsStagingPathInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tsts_ak_id\x18\x02 \x01(\t\x12\x15\n\rsts_ak_secret\x18\x03 \x01(\t\x12\x11\n\tsts_token\x18\x04 \x01(\t\x12\x12\n\ngcs_region\x18\x05 \x01(\t\x12\x17\n\x0fgcs_expire_time\x18\x06 \x01(\x04\"\x8e\x01\n\x12ObsStagingPathInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tsts_ak_id\x18\x02 \x01(\t\x12\x15\n\rsts_ak_secret\x18\x03 \x01(\t\x12\x11\n\tsts_token\x18\x04 \x01(\t\x12\x14\n\x0cobs_endpoint\x18\x05 \x01(\t\x12\x17\n\x0fobs_expire_time\x18\x06 \x01(\x04\"\x8e\x01\n\x12TosStagingPathInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tsts_ak_id\x18\x02 \x01(\t\x12\x15\n\rsts_ak_secret\x18\x03 \x01(\t\x12\x11\n\tsts_token\x18\x04 \x01(\t\x12\x14\n\x0ctos_endpoint\x18\x05 \x01(\t\x12\x17\n\x0ftos_expire_time\x18\x06 \x01(\x04\"$\n\x14LocalStagingPathInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xc4\x03\n\x0fStagingPathInfo\x12:\n\x08oss_path\x18\x01 \x01(\x0b\x32&.cz.proto.ingestion.OssStagingPathInfoH\x00\x12:\n\x08\x63os_path\x18\x02 \x01(\x0b\x32&.cz.proto.ingestion.CosStagingPathInfoH\x00\x12>\n\nlocal_path\x18\x03 \x01(\x0b\x32(.cz.proto.ingestion.LocalStagingPathInfoH\x00\x12\x38\n\x07s3_path\x18\x04 \x01(\x0b\x32%.cz.proto.ingestion.S3StagingPathInfoH\x00\x12:\n\x08gcs_path\x18\x05 \x01(\x0b\x32&.cz.proto.ingestion.GcsStagingPathInfoH\x00\x12:\n\x08obs_path\x18\x06 \x01(\x0b\x32&.cz.proto.ingestion.ObsStagingPathInfoH\x00\x12:\n\x08tos_path\x18\x07 \x01(\x0b\x32&.cz.proto.ingestion.TosStagingPathInfoH\x00\x42\x0b\n\tpath_info\"\xa7\x04\n\x12\x42ulkLoadStreamInfo\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12=\n\x0cstream_state\x18\x02 \x01(\x0e\x32\'.cz.proto.ingestion.BulkLoadStreamState\x12\x12\n\nsql_job_id\x18\x03 \x01(\t\x12\x37\n\nidentifier\x18\x04 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12>\n\toperation\x18\x05 \x01(\x0e\x32+.cz.proto.ingestion.BulkLoadStreamOperation\x12\x16\n\x0epartition_spec\x18\x06 \x01(\t\x12\x13\n\x0brecord_keys\x18\x07 \x03(\t\x12\x37\n\rstream_schema\x18\x08 \x01(\x0b\x32 .cz.proto.ingestion.StreamSchema\x12\x15\n\rsql_error_msg\x18\t \x01(\t\x12 \n\x18prefer_internal_endpoint\x18\n \x01(\x08\x12Y\n\x12\x65ncryption_options\x18\x0b \x03(\x0b\x32=.cz.proto.ingestion.BulkLoadStreamInfo.EncryptionOptionsEntry\x1a\x38\n\x16\x45ncryptionOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc9\x01\n\x1a\x42ulkLoadStreamWriterConfig\x12\x39\n\x0cstaging_path\x18\x01 \x01(\x0b\x32#.cz.proto.ingestion.StagingPathInfo\x12-\n\x0b\x66ile_format\x18\x02 \x01(\x0e\x32\x18.cz.proto.FileFormatType\x12\x1d\n\x15max_num_rows_per_file\x18\x03 \x01(\x03\x12\"\n\x1amax_size_in_bytes_per_file\x18\x04 \x01(\x03\"\x93\x02\n\x1b\x43reateBulkLoadStreamRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x37\n\nidentifier\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12>\n\toperation\x18\x03 \x01(\x0e\x32+.cz.proto.ingestion.BulkLoadStreamOperation\x12\x16\n\x0epartition_spec\x18\x04 \x01(\t\x12\x13\n\x0brecord_keys\x18\x05 \x03(\t\x12 \n\x18prefer_internal_endpoint\x18\x06 \x01(\x08\"\x88\x01\n\x1c\x43reateBulkLoadStreamResponse\x12\x32\n\x06status\x18\x01 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\x12\x34\n\x04info\x18\x02 \x01(\x0b\x32&.cz.proto.ingestion.BulkLoadStreamInfo\"\xad\x01\n\x18GetBulkLoadStreamRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x37\n\nidentifier\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x11\n\tstream_id\x18\x03 \x01(\t\x12\x17\n\x0fneed_table_meta\x18\x04 \x01(\x08\"\x85\x01\n\x19GetBulkLoadStreamResponse\x12\x32\n\x06status\x18\x01 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\x12\x34\n\x04info\x18\x02 \x01(\x0b\x32&.cz.proto.ingestion.BulkLoadStreamInfo\"\xeb\x02\n\x1b\x43ommitBulkLoadStreamRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x37\n\nidentifier\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x11\n\tstream_id\x18\x03 \x01(\t\x12\x19\n\x11\x65xecute_workspace\x18\x04 \x01(\t\x12\x17\n\x0f\x65xecute_vc_name\x18\x05 \x01(\t\x12O\n\x0b\x63ommit_mode\x18\x06 \x01(\x0e\x32:.cz.proto.ingestion.CommitBulkLoadStreamRequest.CommitMode\x12\x1a\n\x12spec_partition_ids\x18\x07 \x03(\r\"1\n\nCommitMode\x12\x11\n\rCOMMIT_STREAM\x10\x00\x12\x10\n\x0c\x41\x42ORT_STREAM\x10\x01\"\x88\x01\n\x1c\x43ommitBulkLoadStreamResponse\x12\x32\n\x06status\x18\x01 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\x12\x34\n\x04info\x18\x02 \x01(\x0b\x32&.cz.proto.ingestion.BulkLoadStreamInfo\"\xb1\x01\n\x1fOpenBulkLoadStreamWriterRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x37\n\nidentifier\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x11\n\tstream_id\x18\x03 \x01(\t\x12\x14\n\x0cpartition_id\x18\x04 \x01(\r\"\x96\x01\n OpenBulkLoadStreamWriterResponse\x12\x32\n\x06status\x18\x01 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\x12>\n\x06\x63onfig\x18\x02 \x01(\x0b\x32..cz.proto.ingestion.BulkLoadStreamWriterConfig\"\xe3\x01\n!FinishBulkLoadStreamWriterRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x37\n\nidentifier\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x11\n\tstream_id\x18\x03 \x01(\t\x12\x14\n\x0cpartition_id\x18\x04 \x01(\r\x12\x15\n\rwritten_files\x18\x05 \x03(\t\x12\x17\n\x0fwritten_lengths\x18\x06 \x03(\x04\"X\n\"FinishBulkLoadStreamWriterResponse\x12\x32\n\x06status\x18\x01 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\"\x9c\x01\n\x16GetRouteWorkersRequest\x12\x38\n\x0btable_ident\x18\x01 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x35\n\x0c\x63onnect_mode\x18\x02 \x01(\x0e\x32\x1f.cz.proto.ingestion.ConnectMode\x12\x11\n\ttablet_id\x18\x03 \x03(\x03\"+\n\rHostPortTuple\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\x92\x01\n\x17GetRouteWorkersResponse\x12\x30\n\x05tuple\x18\x01 \x03(\x0b\x32!.cz.proto.ingestion.HostPortTuple\x12\x11\n\ttablet_id\x18\x02 \x03(\x03\x12\x32\n\x06status\x18\x03 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\"H\n\x11OperationTypeList\x12\x33\n\x08op_types\x18\x01 \x03(\x0e\x32!.cz.proto.ingestion.OperationType\"\xf6\x01\n\tDataBlock\x12\x15\n\rarrow_payload\x18\x01 \x01(\x0c\x12\x1e\n\x16is_set_bitmaps_payload\x18\x02 \x01(\x0c\x12\x41\n\x10row_op_type_list\x18\x03 \x01(\x0b\x32%.cz.proto.ingestion.OperationTypeListH\x00\x12:\n\rblock_op_type\x18\x04 \x01(\x0e\x32!.cz.proto.ingestion.OperationTypeH\x00\x12\x11\n\tbucket_id\x18\x05 \x01(\r\x12\x10\n\x08num_rows\x18\x06 \x01(\rB\x0e\n\x0cop_type_info\"c\n\x0fMutateRowStatus\x12&\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x18.cz.proto.ingestion.Code\x12\x15\n\rerror_message\x18\x02 \x01(\t\x12\x11\n\trow_index\x18\x03 \x01(\x05\"\xd6\x01\n\rMutateRequest\x12,\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1b.cz.proto.ingestion.Account\x12\x38\n\x0btable_ident\x18\x02 \x01(\x0b\x32#.cz.proto.ingestion.TableIdentifier\x12\x10\n\x08\x62\x61tch_id\x18\x03 \x01(\x03\x12\x17\n\x0fwrite_timestamp\x18\x04 \x01(\x03\x12\x32\n\x0b\x64\x61ta_blocks\x18\x05 \x03(\x0b\x32\x1d.cz.proto.ingestion.DataBlock\"\xa6\x01\n\x0eMutateResponse\x12\x10\n\x08\x62\x61tch_id\x18\x01 \x01(\x03\x12\x10\n\x08num_rows\x18\x02 \x01(\x03\x12\x32\n\x06status\x18\x03 \x01(\x0b\x32\".cz.proto.ingestion.ResponseStatus\x12<\n\x0frow_status_list\x18\x04 \x03(\x0b\x32#.cz.proto.ingestion.MutateRowStatus*\x91\x05\n\nMethodEnum\x12\x14\n\x10GATEWAY_RPC_CALL\x10\x00\x12\x12\n\x0eGET_TABLE_META\x10\x01\x12\x11\n\rCREATE_TABLET\x10\x02\x12\x15\n\x11GET_MUTATE_WORKER\x10\x03\x12\x11\n\rCOMMIT_TABLET\x10\x04\x12\x0f\n\x0b\x44ROP_TABLET\x10\x05\x12\x16\n\x12\x43HECK_TABLE_EXISTS\x10\x06\x12\x19\n\x15\x43REATE_PENDING_STREAM\x10\x07\x12\x19\n\x15\x43OMMIT_PENDING_STREAM\x10\x08\x12\x16\n\x12GET_PENDING_STREAM\x10\t\x12\x17\n\x13JOIN_PENDING_STREAM\x10\n\x12\x1b\n\x17\x43REATE_BULK_LOAD_STREAM\x10\x0b\x12\x18\n\x14GET_BULK_LOAD_STREAM\x10\x0c\x12\x1b\n\x17\x43OMMIT_BULK_LOAD_STREAM\x10\r\x12 \n\x1cOPEN_BULK_LOAD_STREAM_WRITER\x10\x0e\x12\"\n\x1e\x46INISH_BULK_LOAD_STREAM_WRITER\x10\x0f\x12\x1b\n\x17\x43REATE_OR_GET_STREAM_V2\x10\x10\x12\x13\n\x0f\x43LOSE_STREAM_V2\x10\x11\x12\x17\n\x13GET_ROUTE_WORKER_V2\x10\x12\x12\x1e\n\x1a\x43REATE_BULK_LOAD_STREAM_V2\x10\x13\x12\x1b\n\x17GET_BULK_LOAD_STREAM_V2\x10\x14\x12\x1e\n\x1a\x43OMMIT_BULK_LOAD_STREAM_V2\x10\x15\x12#\n\x1fOPEN_BULK_LOAD_STREAM_WRITER_V2\x10\x16\x12%\n!FINISH_BULK_LOAD_STREAM_WRITER_V2\x10\x17*1\n\x0cIGSTableType\x12\n\n\x06NORMAL\x10\x00\x12\x0b\n\x07\x43LUSTER\x10\x01\x12\x08\n\x04\x41\x43ID\x10\x02*.\n\x04\x43ode\x12\x0b\n\x07SUCCESS\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\r\n\tTHROTTLED\x10\x02*\x8c\x01\n\x13\x42ulkLoadStreamState\x12\x0e\n\nBL_CREATED\x10\x00\x12\r\n\tBL_SEALED\x10\x01\x12\x17\n\x13\x42L_COMMIT_SUBMITTED\x10\x02\x12\x15\n\x11\x42L_COMMIT_SUCCESS\x10\x03\x12\x14\n\x10\x42L_COMMIT_FAILED\x10\x04\x12\x10\n\x0c\x42L_CANCELLED\x10\x05*I\n\x17\x42ulkLoadStreamOperation\x12\r\n\tBL_APPEND\x10\x00\x12\x10\n\x0c\x42L_OVERWRITE\x10\x01\x12\r\n\tBL_UPSERT\x10\x02*<\n\x0b\x43onnectMode\x12\n\n\x06\x44IRECT\x10\x00\x12\x0b\n\x07GATEWAY\x10\x01\x12\x14\n\x10GATEWAY_INTERNAL\x10\x02*\x85\x01\n\rOperationType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06INSERT\x10\x01\x12\n\n\x06UPDATE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPSERT\x10\x04\x12\x11\n\rINSERT_IGNORE\x10\x05\x12\x11\n\rUPDATE_IGNORE\x10\x06\x12\x11\n\rDELETE_IGNORE\x10\x07\x32\xb3\x08\n\x1aIngestionControllerService\x12Y\n\x0eGatewayRpcCall\x12\".cz.proto.ingestion.GatewayRequest\x1a#.cz.proto.ingestion.GatewayResponse\x12p\n\x11\x43reateOrGetStream\x12,.cz.proto.ingestion.CreateOrGetStreamRequest\x1a-.cz.proto.ingestion.CreateOrGetStreamResponse\x12^\n\x0b\x43loseStream\x12&.cz.proto.ingestion.CloseStreamRequest\x1a\'.cz.proto.ingestion.CloseStreamResponse\x12j\n\x0fGetRouteWorkers\x12*.cz.proto.ingestion.GetRouteWorkersRequest\x1a+.cz.proto.ingestion.GetRouteWorkersResponse\x12y\n\x14\x43reateBulkLoadStream\x12/.cz.proto.ingestion.CreateBulkLoadStreamRequest\x1a\x30.cz.proto.ingestion.CreateBulkLoadStreamResponse\x12p\n\x11GetBulkLoadStream\x12,.cz.proto.ingestion.GetBulkLoadStreamRequest\x1a-.cz.proto.ingestion.GetBulkLoadStreamResponse\x12y\n\x14\x43ommitBulkLoadStream\x12/.cz.proto.ingestion.CommitBulkLoadStreamRequest\x1a\x30.cz.proto.ingestion.CommitBulkLoadStreamResponse\x12\x85\x01\n\x18OpenBulkLoadStreamWriter\x12\x33.cz.proto.ingestion.OpenBulkLoadStreamWriterRequest\x1a\x34.cz.proto.ingestion.OpenBulkLoadStreamWriterResponse\x12\x8b\x01\n\x1a\x46inishBulkLoadStreamWriter\x12\x35.cz.proto.ingestion.FinishBulkLoadStreamWriterRequest\x1a\x36.cz.proto.ingestion.FinishBulkLoadStreamWriterResponse2\xca\x01\n\x16IngestionWorkerService\x12S\n\x06Mutate\x12!.cz.proto.ingestion.MutateRequest\x1a\".cz.proto.ingestion.MutateResponse(\x01\x30\x01\x12[\n\x0eMutateInternal\x12!.cz.proto.ingestion.MutateRequest\x1a\".cz.proto.ingestion.MutateResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ingestion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BULKLOADSTREAMINFO_ENCRYPTIONOPTIONSENTRY']._loaded_options = None
  _globals['_BULKLOADSTREAMINFO_ENCRYPTIONOPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_METHODENUM']._serialized_start=6987
  _globals['_METHODENUM']._serialized_end=7644
  _globals['_IGSTABLETYPE']._serialized_start=7646
  _globals['_IGSTABLETYPE']._serialized_end=7695
  _globals['_CODE']._serialized_start=7697
  _globals['_CODE']._serialized_end=7743
  _globals['_BULKLOADSTREAMSTATE']._serialized_start=7746
  _globals['_BULKLOADSTREAMSTATE']._serialized_end=7886
  _globals['_BULKLOADSTREAMOPERATION']._serialized_start=7888
  _globals['_BULKLOADSTREAMOPERATION']._serialized_end=7961
  _globals['_CONNECTMODE']._serialized_start=7963
  _globals['_CONNECTMODE']._serialized_end=8023
  _globals['_OPERATIONTYPE']._serialized_start=8026
  _globals['_OPERATIONTYPE']._serialized_end=8159
  _globals['_GATEWAYREQUEST']._serialized_start=80
  _globals['_GATEWAYREQUEST']._serialized_end=174
  _globals['_GATEWAYRESPONSE']._serialized_start=176
  _globals['_GATEWAYRESPONSE']._serialized_end=269
  _globals['_USERIDENTIFIER']._serialized_start=271
  _globals['_USERIDENTIFIER']._serialized_end=363
  _globals['_ACCOUNT']._serialized_start=365
  _globals['_ACCOUNT']._serialized_end=445
  _globals['_TABLEIDENTIFIER']._serialized_start=447
  _globals['_TABLEIDENTIFIER']._serialized_end=545
  _globals['_GATEWAYRESPONSESTATUS']._serialized_start=547
  _globals['_GATEWAYRESPONSESTATUS']._serialized_end=647
  _globals['_RESPONSESTATUS']._serialized_start=649
  _globals['_RESPONSESTATUS']._serialized_end=748
  _globals['_DATAFIELD']._serialized_start=750
  _globals['_DATAFIELD']._serialized_end=809
  _globals['_DISTRIBUTIONSPEC']._serialized_start=811
  _globals['_DISTRIBUTIONSPEC']._serialized_end=893
  _globals['_PRIMARYKEYSPEC']._serialized_start=895
  _globals['_PRIMARYKEYSPEC']._serialized_end=930
  _globals['_PARTITIONSPEC']._serialized_start=932
  _globals['_PARTITIONSPEC']._serialized_end=970
  _globals['_STREAMSCHEMA']._serialized_start=973
  _globals['_STREAMSCHEMA']._serialized_end=1217
  _globals['_CREATEORGETSTREAMREQUEST']._serialized_start=1220
  _globals['_CREATEORGETSTREAMREQUEST']._serialized_end=1371
  _globals['_CREATEORGETSTREAMRESPONSE']._serialized_start=1374
  _globals['_CREATEORGETSTREAMRESPONSE']._serialized_end=1590
  _globals['_CLOSESTREAMREQUEST']._serialized_start=1592
  _globals['_CLOSESTREAMREQUEST']._serialized_end=1716
  _globals['_CLOSESTREAMRESPONSE']._serialized_start=1718
  _globals['_CLOSESTREAMRESPONSE']._serialized_end=1791
  _globals['_OSSSTAGINGPATHINFO']._serialized_start=1794
  _globals['_OSSSTAGINGPATHINFO']._serialized_end=1967
  _globals['_COSSTAGINGPATHINFO']._serialized_start=1970
  _globals['_COSSTAGINGPATHINFO']._serialized_end=2110
  _globals['_S3STAGINGPATHINFO']._serialized_start=2113
  _globals['_S3STAGINGPATHINFO']._serialized_end=2250
  _globals['_GCSSTAGINGPATHINFO']._serialized_start=2253
  _globals['_GCSSTAGINGPATHINFO']._serialized_end=2393
  _globals['_OBSSTAGINGPATHINFO']._serialized_start=2396
  _globals['_OBSSTAGINGPATHINFO']._serialized_end=2538
  _globals['_TOSSTAGINGPATHINFO']._serialized_start=2541
  _globals['_TOSSTAGINGPATHINFO']._serialized_end=2683
  _globals['_LOCALSTAGINGPATHINFO']._serialized_start=2685
  _globals['_LOCALSTAGINGPATHINFO']._serialized_end=2721
  _globals['_STAGINGPATHINFO']._serialized_start=2724
  _globals['_STAGINGPATHINFO']._serialized_end=3176
  _globals['_BULKLOADSTREAMINFO']._serialized_start=3179
  _globals['_BULKLOADSTREAMINFO']._serialized_end=3730
  _globals['_BULKLOADSTREAMINFO_ENCRYPTIONOPTIONSENTRY']._serialized_start=3674
  _globals['_BULKLOADSTREAMINFO_ENCRYPTIONOPTIONSENTRY']._serialized_end=3730
  _globals['_BULKLOADSTREAMWRITERCONFIG']._serialized_start=3733
  _globals['_BULKLOADSTREAMWRITERCONFIG']._serialized_end=3934
  _globals['_CREATEBULKLOADSTREAMREQUEST']._serialized_start=3937
  _globals['_CREATEBULKLOADSTREAMREQUEST']._serialized_end=4212
  _globals['_CREATEBULKLOADSTREAMRESPONSE']._serialized_start=4215
  _globals['_CREATEBULKLOADSTREAMRESPONSE']._serialized_end=4351
  _globals['_GETBULKLOADSTREAMREQUEST']._serialized_start=4354
  _globals['_GETBULKLOADSTREAMREQUEST']._serialized_end=4527
  _globals['_GETBULKLOADSTREAMRESPONSE']._serialized_start=4530
  _globals['_GETBULKLOADSTREAMRESPONSE']._serialized_end=4663
  _globals['_COMMITBULKLOADSTREAMREQUEST']._serialized_start=4666
  _globals['_COMMITBULKLOADSTREAMREQUEST']._serialized_end=5029
  _globals['_COMMITBULKLOADSTREAMREQUEST_COMMITMODE']._serialized_start=4980
  _globals['_COMMITBULKLOADSTREAMREQUEST_COMMITMODE']._serialized_end=5029
  _globals['_COMMITBULKLOADSTREAMRESPONSE']._serialized_start=5032
  _globals['_COMMITBULKLOADSTREAMRESPONSE']._serialized_end=5168
  _globals['_OPENBULKLOADSTREAMWRITERREQUEST']._serialized_start=5171
  _globals['_OPENBULKLOADSTREAMWRITERREQUEST']._serialized_end=5348
  _globals['_OPENBULKLOADSTREAMWRITERRESPONSE']._serialized_start=5351
  _globals['_OPENBULKLOADSTREAMWRITERRESPONSE']._serialized_end=5501
  _globals['_FINISHBULKLOADSTREAMWRITERREQUEST']._serialized_start=5504
  _globals['_FINISHBULKLOADSTREAMWRITERREQUEST']._serialized_end=5731
  _globals['_FINISHBULKLOADSTREAMWRITERRESPONSE']._serialized_start=5733
  _globals['_FINISHBULKLOADSTREAMWRITERRESPONSE']._serialized_end=5821
  _globals['_GETROUTEWORKERSREQUEST']._serialized_start=5824
  _globals['_GETROUTEWORKERSREQUEST']._serialized_end=5980
  _globals['_HOSTPORTTUPLE']._serialized_start=5982
  _globals['_HOSTPORTTUPLE']._serialized_end=6025
  _globals['_GETROUTEWORKERSRESPONSE']._serialized_start=6028
  _globals['_GETROUTEWORKERSRESPONSE']._serialized_end=6174
  _globals['_OPERATIONTYPELIST']._serialized_start=6176
  _globals['_OPERATIONTYPELIST']._serialized_end=6248
  _globals['_DATABLOCK']._serialized_start=6251
  _globals['_DATABLOCK']._serialized_end=6497
  _globals['_MUTATEROWSTATUS']._serialized_start=6499
  _globals['_MUTATEROWSTATUS']._serialized_end=6598
  _globals['_MUTATEREQUEST']._serialized_start=6601
  _globals['_MUTATEREQUEST']._serialized_end=6815
  _globals['_MUTATERESPONSE']._serialized_start=6818
  _globals['_MUTATERESPONSE']._serialized_end=6984
  _globals['_INGESTIONCONTROLLERSERVICE']._serialized_start=8162
  _globals['_INGESTIONCONTROLLERSERVICE']._serialized_end=9237
  _globals['_INGESTIONWORKERSERVICE']._serialized_start=9240
  _globals['_INGESTIONWORKERSERVICE']._serialized_end=9442
# @@protoc_insertion_point(module_scope)
