# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: file_format_type.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'file_format_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x66ile_format_type.proto\x12\x08\x63z.proto*\x83\x01\n\x0e\x46ileFormatType\x12\x08\n\x04TEXT\x10\x00\x12\x0b\n\x07PARQUET\x10\x01\x12\x07\n\x03ORC\x10\x02\x12\x08\n\x04\x41VRO\x10\x03\x12\x07\n\x03\x43SV\x10\x04\x12\t\n\x05\x41RROW\x10\x05\x12\x0f\n\x0bHIVE_RESULT\x10`\x12\t\n\x05\x44UMMY\x10\x61\x12\n\n\x06MEMORY\x10\x62\x12\x0b\n\x07ICEBERG\x10\x63\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'file_format_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FILEFORMATTYPE']._serialized_start=37
  _globals['_FILEFORMATTYPE']._serialized_end=168
# @@protoc_insertion_point(module_scope)
